@@ -8,7 +8,7 @@ from manoutils.config.ConfigManager import configMgr
 from manoutils.common.constant import BASE1_HEADERS
 from manoutils.common.common import ignore_case_get
 
-logger = logging.getLogger(__name__)
+logger = configMgr.getLogger()
 
 
 class CertClient(object):
